@@ -276,7 +276,20 @@ class KinesisFirehoseToAnalyticsAndS3(
         :summary: Constructs a new instance of the KinesisFirehoseToAnalyticsAndS3 class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisFirehoseToAnalyticsAndS3.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                kinesis_analytics_props: typing.Optional[typing.Union[aws_cdk.aws_kinesisanalytics.CfnApplicationProps, typing.Dict[str, typing.Any]]] = None,
+                kinesis_firehose_props: typing.Any = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisFirehoseToAnalyticsAndS3Props(
@@ -371,7 +384,18 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(KinesisFirehoseToAnalyticsAndS3Props.__init__)
+            def stub(
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                kinesis_analytics_props: typing.Optional[typing.Union[aws_cdk.aws_kinesisanalytics.CfnApplicationProps, typing.Dict[str, typing.Any]]] = None,
+                kinesis_firehose_props: typing.Any = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
             check_type(argname="argument kinesis_analytics_props", value=kinesis_analytics_props, expected_type=type_hints["kinesis_analytics_props"])
